@@ -126,8 +126,8 @@ class ColorPickerMixin:
             An optional callback invoked when this color_picker's value
             changes.
 
-        args : tuple
-            An optional tuple of args to pass to the callback.
+        args : list or tuple
+            An optional list or tuple of args to pass to the callback.
 
         kwargs : dict
             An optional dict of kwargs to pass to the callback.
